<?php

class CPTGenerator
{
    public $annotations = "annotationGenerators:\n    - ApiPlatform\SchemaGenerator\AnnotationGenerator\PhpDocAnnotationGenerator\n    - ApiPlatform\SchemaGenerator\AnnotationGenerator\DoctrineOrmAnnotationGenerator\n    - ApiPlatform\SchemaGenerator\AnnotationGenerator\ConstraintAnnotationGenerator\n";

    protected $namespaces = [
        "entity" => "Entity"
    ];

    const EXCLUDED_POST_TYPE_SLUGS = [
        'nav_menu_item',
    ];

	/**
	 * Generate a representation of the yaml file as an array
	 *
	 * @param string $postType Optional. String name of post type
	 *
	 * @return array An array of post type names
	 */
    public function generate($postType = ''): array
    {
        if ($postType !== '') {
            $selectedPostTypes = $this->generateOnePost($postType);
        } else {
            $allPostTypes = $this->getAllPostTypes();
            $selectedPostTypes = [];
            foreach ($allPostTypes as $postType) {
                $selectedPostTypes = array_merge($selectedPostTypes, $this->generateOnePost($postType));
            }
        }

        $array = [
            "namespaces" => $this->namespaces,
            "types" => $selectedPostTypes
        ];

        return $array;
    }

	/**
	 * Get all custom post types
	 *
	 * @return array
	 */
    public function getAllPostTypes()
    {
        $result = [];
        $allPostTypes = get_post_types();
        foreach ($allPostTypes as $postType) {
            $isPostTypeExcluded = !in_array($postType, self::EXCLUDED_POST_TYPE_SLUGS);
            if($isPostTypeExcluded){
                $result[] = $postType;
            }
        }
        return $result;
    }

    protected function generateOnePost($postType)
    {
        $selectedPostTypes[$postType] = [
            'properties' => [
                'title' => "~",
                'content' => "~"
            ]
        ];

        $customFieldsToBeAdded = $this->getCustomFields($postType);
        if ($customFieldsToBeAdded) {
            $selectedPostTypes[$postType]['properties'] = array_merge($selectedPostTypes[$postType]['properties'], $customFieldsToBeAdded);
        }

        $taxonomies = get_object_taxonomies($postType, 'objects');
        foreach ($taxonomies as $taxonomySlug => $taxonomy) {
            $selectedPostTypes[$postType]['properties'][$taxonomySlug] = [
                'range' => $taxonomySlug,
                'cardinality' => "(1..*)",
            ];
            // (1..*)
            // (*..0)
        }

        foreach ($taxonomies as  $taxonomySlug => $taxonomy) {
            $selectedPostTypes[$taxonomySlug] = [
                'properties' => [
                    'name' => "~",
                    'description' => "~"
                ]
            ];
        }
        // parent category

        return $selectedPostTypes;
    }

    private function getCustomFields($postType): array
    {
        $customFieldsToBeAdded = [];
        $posts = get_posts([
            'post_type' => $postType,
            'numberposts' => 1,
        ]);
        if (isset($posts[0])) {
            $customFields = get_post_custom_keys($posts[0]->ID);
            if ($customFields) {
                foreach ($customFields as $customField) {
                    $isServiceField = $customField[0] == '_';
                    if (!$isServiceField) {
                        $customFieldsToBeAdded[$customField] = '~';
                    }
                }
            }
        }
        return $customFieldsToBeAdded;
    }
}
