<?php
/**
 * @package CPT_Export
 * @version 1.0.0
 */
/*
Plugin Name: model-exporter
Description: model-exporter
Author: Andrey Koptevich
Text Domain: export-custom-post-type
Version: 1.0.0
*/

/**
 * Load our main menu.
 *
 * Submenu items added in version 1.1.0
 *
 * @since 0.1.0
 *
 * @internal
 */
function cpt_plugin_menu() {

    /**
     * Filters the required capability to manage CPT settings.
     *
     * @since 1.3.0
     *
     * @param string $value Capability required.
     */
    $capability  = apply_filters( 'cpt_required_capabilities', 'manage_options' );
    $parent_slug = 'cpt_main_menu';

    add_menu_page( __( 'Custom Post Types', 'export-custom-post-type' ), __( 'Model-exporter Export all types', 'export-custom-post-type' ), $capability, $parent_slug, 'exportAllTypesToYaml', cptui_menu_icon() );
    add_submenu_page( $parent_slug, __( 'Add/Edit Post Types', 'export-custom-post-type' ), __( 'Model-exporter Export custom post types', 'export-custom-post-type' ), $capability, 'exportCustomPostTypesToYaml', 'exportCustomPostTypesToYaml' );
}

add_action( 'admin_menu', 'cpt_plugin_menu' );

function cpt_loaded() {

    /**
     * Fires upon plugins_loaded WordPress hook.
     *
     * CPTUI loads its required files on this hook.
     *
     * @since 1.3.0
     */
    do_action( 'cpt_loaded' );
}
add_action( 'plugins_loaded', 'cpt_loaded' );

/**
 * Load our submenus.
 *
 * @since 1.0.0
 *
 * @internal
 */
function cpt_create_submenus() {
    require_once( plugin_dir_path( __FILE__ ) . 'inc/export-all-types.php' );
    require_once( plugin_dir_path( __FILE__ ) . 'inc/export-custom-post-types.php' );
}
add_action( 'cpt_loaded', 'cpt_create_submenus' );
