<?php
declare(strict_types=1);

use PHPUnit\Framework\TestCase;

class CPTGeneratorTest extends TestCase
{
	public function testGenerateOnePostType()
	{
		$expectedYamlStructure = [
			'namespaces' => [
				'entity' => 'Entity'
			],
			'types' => [
				'post' => [
					'properties' => [
						'title' => '~',
						'content' => '~',
						'category' => [
							'range' => 'category',
							'cardinality' => "(1..*)"
						],
						'post_tag' => [
							'range' => 'post_tag',
							'cardinality' => "(1..*)"
						],
						'post_format' => [
							'range' => 'post_format',
							'cardinality' => "(1..*)"
						]
					]
				],
				'category' => [
					'properties' => [
						'name' => '~',
						'description' => '~'
					]
				],
				'post_tag' => [
					'properties' => [
						'name' => '~',
						'description' => '~'
					]
				],
				'post_format' => [
					'properties' => [
						'name' => '~',
						'description' => '~'
					]
				]
			]
		];

		$postType = "post";
		$generator = new CPTGenerator();
		$yamlStructure = $generator->generate($postType);

		$this->assertEquals($expectedYamlStructure, $yamlStructure);
	}

	public function testGetAllPostTypes()
	{
		$expectedAllPostTypes = [
			'post',
			'page',
			'attachment',
			'revision',
			'custom_css',
			'customize_changeset',
			'oembed_cache',
			'user_request',
			'wp_block'
		];

		$generator = new CPTGenerator();
		$allPostTypes = $generator->getAllPostTypes();

		$this->assertEquals($expectedAllPostTypes, $allPostTypes);
	}
}
